@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
 
-Copyright (C) 2001 Lukas Tinkl <lukas@kde.org>
+Copyright (C) 2001, 2003 Lukas Tinkl <lukas@kde.org>
 Andreas Schlapbach <schlpbch@iam.unibe.ch>
 
 This library is free software; you can redistribute it and/or
@@ -14,8 +14,8 @@ Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.
+the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+Boston, MA 02110-1301, USA.
 */
 
 #ifndef kimgalleryplugin_h
@@ -26,10 +26,9 @@ Boston, MA 02111-1307, USA.
 #include <konq_dirpart.h>
 #include <kio/jobclasses.h>
 
-#include "imgallerydialog.h"
-
 class QProgressDialog;
 class KURL;
+class KIGPDialog;
 
 typedef QMap<QString,QString> CommentMap;
 
@@ -53,8 +52,8 @@ class KImGalleryPlugin : public KParts::Plugin
 
   int m_imgWidth;
   int m_imgHeight;
-  int m_imagesPerRow;  
- 
+  int m_imagesPerRow;
+
   QProgressDialog *m_progressDlg;
 
   KonqDirPart* m_part;
@@ -67,13 +66,15 @@ class KImGalleryPlugin : public KParts::Plugin
 
   void createHead(QTextStream& stream);
   void createCSSSection(QTextStream& stream);
-  void createBody(QTextStream& stream, const QString& sourceDirName, const QStringList& subDirList, const QDir& imageDir, const KURL& url);
-  
-  bool createThumb( const QString& imgName, const QString& sourceDirName, const QString& imgGalleryDir );
+  void createBody(QTextStream& stream, const QString& sourceDirName, const QStringList& subDirList, const QDir& imageDir, const KURL& url, const QString& imageFormat);
 
-  bool createHtml( const KURL& url, const QString& sourceDirName, int recursionLevel );
-  void deleteCancelledGallery( const KURL& url, const QString& sourceDirName, int recursionLevel );
+  bool createThumb( const QString& imgName, const QString& sourceDirName, const QString& imgGalleryDir, const QString& imageFormat);
+
+  bool createHtml( const KURL& url, const QString& sourceDirName, int recursionLevel, const QString& imageFormat);
+  void deleteCancelledGallery( const KURL& url, const QString& sourceDirName, int recursionLevel, const QString& imageFormat);
   void loadCommentFile();
+
+  static QString extension(const QString& imageFormat);
 };
 
 #endif
