@@ -2,7 +2,7 @@
  *   Copyright (C) 2002, Anders Lund <anders@alweb.dk>                     *
  *   Copyright (C) 2003, 2004, Franck Qulain <shift@free.fr>              *
  *   Copyright (C) 2004, Kevin Krammer <kevin.krammer@gmx.at>              *
- *   Copyright (C) 2004, 2005, Oliviet Goffart <ogoffart @ kde.org>        *
+ *   Copyright (C) 2004, 2006, Oliviet Goffart <ogoffart @ kde.org>        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -294,7 +294,7 @@ void RelLinksPlugin::updateToolbar() {
         QString lrel = getLinkType(rel.lower());
         // relation to ignore
         if (lrel.isEmpty()) continue;
-	kdDebug() << "lrel=" << lrel << endl;
+//	kdDebug() << "lrel=" << lrel << endl;
 
         // -- Retrieve of other usefull informations --
 
@@ -364,8 +364,8 @@ void RelLinksPlugin::updateToolbar() {
 
 void RelLinksPlugin::guessRelations()
 {
-	KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
-	if (!part)
+	m_part = dynamic_cast<KHTMLPart *>(parent());
+	if (!m_part || m_part->document().isNull() )
 		return;
 	
 	//If the page already contains some link, that mean the webmaster is aware
@@ -382,7 +382,7 @@ void RelLinksPlugin::guessRelations()
 	
 	
 	const QString zeros("0000");
-	QString url=part->url().url();
+	QString url=m_part->url().url();
 	if(rx.search(url)!=-1)
 	{
 		uint val=rx.cap(2).toUInt();
